[![Flake8 linter Actions Status](https://github.com/gerrowadat/mqttbow/workflows/Flake8%20linter/badge.svg)](https://github.com/gerrowadat/mqttbow/actions)
# mqttbow
An MQTT client for the pimoroni keybow.

Shopping list:
  - Raspberry Pi Model Zero (the last hassle is getting the WH model which has wifi and headers already on).
  - Pimoroni [Keybow](https://shop.pimoroni.com/products/keybow) or Keybow MINI (I'm using a Mini but will aim to have it work for both).
